@@ -17,13 +17,13 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2018 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2020 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    https://www.imagemagick.org/script/license.php                           %
+%    https://imagemagick.org/script/license.php                               %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -92,7 +92,7 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
   ExceptionInfo *exception)
 {
   char
-    geometry[MaxTextExtent],
+    geometry[MagickPathExtent],
     *label;
 
   DrawInfo
@@ -138,9 +138,7 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
       ThrowReaderException(ImageError,"WidthOrHeightExceedsLimit");
     }
   draw_info->text=ConstantString(label);
-  metrics.width=0.0;
-  metrics.height=0.0;
-  metrics.ascent=0.0;
+  (void) memset(&metrics,0,sizeof(metrics));
   status=GetMultilineTypeMetrics(image,draw_info,&metrics);
   if ((image->columns == 0) && (image->rows == 0))
     {
@@ -164,7 +162,7 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
         */
         for (n=0; n < 32; n++, draw_info->pointsize*=2.0)
         {
-          (void) FormatLocaleString(geometry,MaxTextExtent,"%+g%+g",
+          (void) FormatLocaleString(geometry,MagickPathExtent,"%+g%+g",
             -metrics.bounds.x1,metrics.ascent);
           if (draw_info->gravity == UndefinedGravity)
             (void) CloneString(&draw_info->geometry,geometry);
@@ -194,7 +192,7 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
         for (low=1.0; (high-low) > 0.5; )
         {
           draw_info->pointsize=(low+high)/2.0;
-          (void) FormatLocaleString(geometry,MaxTextExtent,"%+g%+g",
+          (void) FormatLocaleString(geometry,MagickPathExtent,"%+g%+g",
             -metrics.bounds.x1,metrics.ascent);
           if (draw_info->gravity == UndefinedGravity)
             (void) CloneString(&draw_info->geometry,geometry);
@@ -219,7 +217,7 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
         }
         if (status != MagickFalse)
           {
-            draw_info->pointsize=(low+high)/2.0-0.5;
+            draw_info->pointsize=floor((low+high)/2.0-0.5);
             status=GetMultilineTypeMetrics(image,draw_info,&metrics);
           }
       }
@@ -259,18 +257,18 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
   /*
     Draw label.
   */
-  (void) FormatLocaleString(geometry,MaxTextExtent,"%+g%+g",
-    draw_info->direction == RightToLeftDirection ? (double) image->columns-
-    metrics.bounds.x2 : 0.0,draw_info->gravity == UndefinedGravity ?
-    MagickMax(metrics.ascent,metrics.bounds.y2) : 0.0);
+  (void) FormatLocaleString(geometry,MagickPathExtent,"%+g%+g",
+    (draw_info->direction == RightToLeftDirection ? (double) image->columns-
+    metrics.bounds.x2 : 0.0),(draw_info->gravity == UndefinedGravity ?
+    MagickMax(metrics.ascent,metrics.bounds.y2) : 0.0));
   (void) CloneString(&draw_info->geometry,geometry);
   status=AnnotateImage(image,draw_info);
   if (image_info->pointsize == 0.0)
     {
       char
-        pointsize[MaxTextExtent];
+        pointsize[MagickPathExtent];
 
-      (void) FormatLocaleString(pointsize,MaxTextExtent,"%.20g",
+      (void) FormatLocaleString(pointsize,MagickPathExtent,"%.20g",
         draw_info->pointsize);
       (void) SetImageProperty(image,"label:pointsize",pointsize);
     }
@@ -316,7 +314,7 @@ ModuleExport size_t RegisterLABELImage(void)
   entry->adjoin=MagickFalse;
   entry->format_type=ImplicitFormatType;
   entry->description=ConstantString("Image label");
-  entry->module=ConstantString("LABEL");
+  entry->magick_module=ConstantString("LABEL");
   (void) RegisterMagickInfo(entry);
   return(MagickImageCoderSignature);
 }
