@@ -23,7 +23,7 @@
 %                               February 2000                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2018 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2020 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -660,7 +660,7 @@ MagickExport const IndexPacket *GetCacheViewVirtualIndexQueue(
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  GetCacheViewVirtualPixelQueue() returns the the pixels associated with
+%  GetCacheViewVirtualPixelQueue() returns the pixels associated with
 %  the last call to GetCacheViewVirtualPixels().  The pixels are virtual
 %  and therefore cannot be updated.
 %
